@@ -1,5 +1,5 @@
 module.exports = {
-  parser: 'babel-eslint',
+  parser: 'hermes-eslint',
   extends: [
     require.resolve('./packages/eslint-config-fbjs'),
   ],
