@@ -1,3 +1,4 @@
+/* eslint-disable max-len */
 /**
  * Copyright (c) Facebook, Inc. and its affiliates.
  *
@@ -12,6 +13,7 @@
 const babel = require('@babel/core');
 const inlineRequiresPlugin = require('../inline-requires');
 const pluginTester = require('babel-plugin-tester');
+const validateOutputAst = require('../test-utils/validateOutputAst');
 
 pluginTester({
   plugin: inlineRequiresPlugin,
@@ -53,6 +55,103 @@ pluginTester({
       snapshot: false,
     },
 
+    'ensures that the inlined require still points to the global require function': {
+      code: `
+        const foo = require('foo');
+
+        function test() {
+          function require(condition) {
+            if (!condition) {
+              throw new Error('Condition is falsy');
+            }
+          }
+
+          require(foo.isOnline());
+        }
+        `,
+      snapshot: true,
+    },
+
+    'ensures that the inlined require still points to the global require function with inlineableCalls options': {
+      code: `
+        const foo = customStuff('foo');
+
+        function test() {
+          function customStuff(condition) {
+            if (!condition) {
+              throw new Error('Condition is falsy');
+            }
+          }
+
+          customStuff(foo.isOnline());
+        }
+        `,
+      snapshot: true,
+    },
+
+    'ensures that the inlined require still points to the global require function even if local require is not called': {
+      code: `
+        const foo = require('foo');
+
+        function test() {
+          function require(condition) {
+            if (!condition) {
+              throw new Error('Condition is falsy');
+            }
+          }
+
+          foo.isOnline();
+        }
+        `,
+      snapshot: true,
+    },
+
+    'does not transform require calls if require is redeclared in the same declaration scope': {
+      code: `
+        function require(condition) {
+          if (!condition) {
+            throw new Error('Condition is falsy');
+          }
+        }
+
+        const foo = require('foo');
+
+        console.log(foo.test);
+      `,
+      snapshot: false,
+    },
+
+    'does not transform require calls if require is redeclared in the global scope': {
+      code: `
+        function require(condition) {
+          if (!condition) {
+            throw new Error('Condition is falsy');
+          }
+        }
+
+        function test() {
+          const foo = require('foo');
+          console.log(foo.test);
+        }
+      `,
+      snapshot: false,
+    },
+
+    'does not transform require calls if it is not needed': {
+      code: `
+        function test () {
+          function require(condition) {
+            if (!condition) {
+              throw new Error('The condition is false');
+            }
+          }
+
+          require('test');
+        }
+      `,
+      snapshot: true,
+    },
+
     'inlines requires that are referenced before the require statement': {
       code: [
         'function foo() {',
@@ -201,4 +300,9 @@ describe('inline-requires', () => {
     expectNoLocation(expression);
     expectNoLocation(expression.arguments[0]);
   });
+
+  it('should not emit duplicate nodes', function () {
+    const ast = transform(['var foo = require("foo");', 'foo.bar()', 'foo.baz()']).ast;
+    validateOutputAst(ast);
+  })
 });
